/*
 * Copyright (c) 1998-2005 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.collections;

import java.util.*;

/**
 * Some utility methods for java.util.Maps.
 * 
 * @author TorgilZ
 *
 */
public class KongaMapUtils {

	private KongaMapUtils() {
        // No instances of this class.
	}
	
	/**
	 * Checks two maps for equality. The maps are considered to be equal if they have the same
	 * number of entries and each entry has the same key-value pair, where equality in that case
	 * is defined by the Object.equals(Object) method.
	 * 
	 * @param m1
	 * @param m2
	 * @return <tt>true</tt> if m1 equals m2 according to the definition above.
	 */
	public static boolean equals(Map<?, ?> m1, Map<?, ?> m2) {
		if ( m1.size() != m2.size() )
			return false;
		
		Object key = null;
		Object o1 = null;
		Object o2 = null;
        boolean eq = true;
		for( Iterator<?> it = m1.keySet().iterator(); it.hasNext(); ) {
			key = it.next();
			o1 = m1.get(key);
			o2 = m2.get(key);
			if ( o2 == null ) {
				eq = false;
            }
			else {
				if ( o1.equals(o2) == false ) {
					eq = false;
                }
			}
            if( !eq ) {
                break;
            }
		}
		return eq;
	}
    
    public static <K, V> Map<V, K> reverse(Map<K, V> original, Map<V, K> empty) {
        Map<V, K> reversed = empty;
        for (Map.Entry<K, V> entry : original.entrySet()) {
            reversed.put(entry.getValue(), entry.getKey());
        }
        return reversed;
    }
}
