/*
 * Copyright (c) 1998-2006 Jitterbit, Inc.
 *
 */
package org.jitterbit.util.xml;

import java.io.File;
import java.io.IOException;
import java.io.Reader;

import javax.xml.parsers.DocumentBuilder;
import javax.xml.parsers.DocumentBuilderFactory;
import javax.xml.parsers.ParserConfigurationException;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.xml.sax.InputSource;
import org.xml.sax.SAXException;

/**
 * {@link RootNodeExtractor} implementation that uses a DOM parser to extract
 * the root node.
 * 
 * @author Torgil
 * 
 * @since 1.2
 * 
 */
/*package-private*/
final class DomRootNodeExtractor extends RootNodeExtractor {

    @Override
    public Element extractRoot(File xmlFile) throws KongaXmlException {
        try {
            DocumentBuilder parser = getDomBuilder();
            Document doc = parser.parse(xmlFile);
            return doc.getDocumentElement();
        }
        catch (SAXException ex) {
            throw new KongaXmlException("Failed to parse the specified XML file.", ex);
        }
        catch (IOException ex) {
            throw new KongaXmlException("Failed to read the specified XML file.", ex);
        }
    }

    @Override
    public Element extractRoot(Reader reader) throws KongaXmlException {
        try {
            DocumentBuilder parser = getDomBuilder();
            InputSource is = new InputSource(reader);
            Document doc = parser.parse(is);
            return doc.getDocumentElement();
        }
        catch (SAXException ex) {
            throw new KongaXmlException("Failed to parse the specified XML.", ex);
        }
        catch (IOException ex) {
            throw new KongaXmlException("Failed to read the specified XML.", ex);
        }
    }

    private DocumentBuilder getDomBuilder() throws KongaXmlException {
        try {
            DocumentBuilderFactory f = getDomBuilderFactory();
            return f.newDocumentBuilder();
        }
        catch (ParserConfigurationException ex) {
            throw new KongaXmlException("Failed to create the DOM parser.", ex);
        }
    }
    
    private DocumentBuilderFactory getDomBuilderFactory() {
        DocumentBuilderFactory f = DocumentBuilderFactory.newInstance();
        f.setNamespaceAware(true);
        return f;
    }
}
